@@ -5,7 +5,7 @@ function (n = 131072, p = 65536, q = 1024, r = 65536, s = 65536,
     location = c(700, 550), manager = TRUE, sh.lib.name = NULL) 
 {
     "ok.coco.start" <- function(resultat) {
-        if ((resultat$ifail == .api.version) | (resultat$ifail == 
+        if ((resultat$ifail == CoCoCore::.apiVersion()) | (resultat$ifail == 
             0)) 
             NULL
         else if ((50 <= resultat$ifail) & (resultat$ifail <= 
@@ -13,13 +13,13 @@ function (n = 131072, p = 65536, q = 1024, r = 65536, s = 65536,
             ok.coco(resultat)
         else warning("Old version of CoCo object file")
     }
-    if (!(exists(".coco.loaded") && .coco.loaded)) 
+    if (!(exists(".coco.loaded") && CoCoCore::.CoCoLoaded())) 
         coco.load(sh.lib.name)
-    if (exists("coco.started") && coco.started) {
-        x <- .coco.identifications[, 2] == type
+    if (exists("coco.started") && CoCoCore::.CoCoStarted()) {
+        x <- CoCoCore::.CoCoIdentifications()[, 2] == type
         if (length(x[x]) > 0) {
-            id <- .coco.identifications[x, 1][1]
-            if (id == .fixed.coco) 
+            id <- CoCoCore::.CoCoIdentifications()[x, 1][1]
+            if (id == CoCoCore::.fixedCoCo()) 
                 stop("This version of the shared library file of CoCo is only able to handle one CoCo-object. Use endCoCo()")
         }
     }
@@ -29,8 +29,9 @@ function (n = 131072, p = 65536, q = 1024, r = 65536, s = 65536,
     else
       sub.dir <- "library/CoCo/lib/coco"
     Arg.char <- .get.lib.and.tmp(sub.dir)
-    n.type <- length(.coco.identifications[(.coco.identifications[, 
-        1] != .ended.coco) & (.coco.identifications[, 2] == type), 
+    ci <- CoCoCore::.CoCoIdentifications()
+    n.type <- length(ci[(ci[, 
+        1] != CoCoCore::.endedCoCo()) & (ci[, 2] == type), 
         1])
     if (n.type == 0) 
         sub.code <- NULL
@@ -44,7 +45,7 @@ function (n = 131072, p = 65536, q = 1024, r = 65536, s = 65536,
     cat("\n")
     # my.assign(".char.ok", TRUE, frame = 0)
     my.assign(".current.coco", c(resultat$id, type), frame = 0)
-    my.assign(".coco.identifications", rbind(.coco.identifications, 
-        .current.coco), frame = 0)
+    my.assign(".coco.identifications", rbind(CoCoCore::.CoCoIdentifications(), 
+        object = CoCoCore::.currentCoCo()), frame = 0)
     ok.coco.start(resultat)
 }
