@@ -1,5 +1,5 @@
 "select.cases" <-
-function (set, cell, object = .current.coco) 
+function (set, cell, object = CoCoCore::.currentCoCo()) 
 {
     if ("what" != set) 
         .set.coco.value(object, ".invalid", append = TRUE, list(type = "select.cases", 
