@@ -1,5 +1,5 @@
 "source.coco" <-
-function (file.name, object = .current.coco) 
+function (file.name, object = CoCoCore::.currentCoCo()) 
 {
     call.coco.chars(23, file.name, FALSE, object = object)
 }
